@@ -33,9 +33,10 @@
 #  define KCONFIGGUI_DEPRECATED_NO_EXPORT KCONFIGGUI_NO_EXPORT KCONFIGGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCONFIGGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCONFIGGUI_NO_DEPRECATED
+#    define KCONFIGGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
